#
# spec file for package coredns
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define project github.com/coredns/coredns
Name:           coredns
Version:        1.6.7
Release:        lp152.1.4
Summary:        DNS server written in Go
License:        Apache-2.0
Group:          Productivity/Networking/DNS/Servers
URL:            https://coredns.io
Provides:       dns_daemon
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source10:       Corefile
Source11:       coredns.service
BuildRequires:  fdupes
BuildRequires:  golang(API) >= 1.12

%description
CoreDNS is a DNS server in Go. It has a plugin architecture for
extending it.

CoreDNS can listen for DNS request coming in over UDP/TCP (RFC 1035),
TLS (RFC 7858) and gRPC (not a standard).

%package extras
Summary:        Extra components for the %{name} package
Group:          Productivity/Networking/DNS/Servers
Requires:       %{name} = %{version}
Supplements:    %{name}
BuildArch:      noarch
BuildRequires:  pkgconfig(systemd)

%description extras
Extra components for the %{name} package, to make %{name} usable in a
non-containerized environment (man pages, configuration, unit file).

%prep
%setup -q -a1

%build

# We can't use symlinks here because go-list gets confused by symlinks, so we
# have to copy the source to $HOME/go and then use that as the GOPATH.
export GOPATH=$HOME/go
export PATH=$PATH:$GOPATH/bin
rm -rf $HOME/go/src
mkdir -pv $HOME/go/src/%{project}
find . -mindepth 1 -maxdepth 1 -exec cp -r {} $HOME/go/src/%{project} \;

cd $HOME/go/src/%{project}
go build -v -buildmode=pie -o coredns

%check
# Too many tests fail due to the restricted permissions in the build enviroment.
# Updates must be tested manually.

%install
cd $HOME/go/src/%{project}

# Binaries
install -D -m 0755 %{name} %{buildroot}%{_sbindir}/%{name}
ln -s service %{buildroot}%{_sbindir}/rccoredns
# Configuration
install -D -m 0644 %{SOURCE10} %{buildroot}%{_sysconfdir}/%{name}/Corefile
# systemd service
install -D -m 0644 %{SOURCE11} %{buildroot}%{_unitdir}/%{name}.service
# Manpages
install -d %{buildroot}/%{_mandir}/man1
install -m 0644 man/coredns*.1 %{buildroot}/%{_mandir}/man1
install -d %{buildroot}/%{_mandir}/man5
install -m 0644 man/corefile*.5 %{buildroot}/%{_mandir}/man5
install -d %{buildroot}/%{_mandir}/man7
install -m 0644 man/coredns-*.7 %{buildroot}/%{_mandir}/man7

%fdupes %{buildroot}/%{_prefix}

%pre extras
%service_add_pre %{name}.service

%post extras
%service_add_post %{name}.service
%{fillup_only -n coredns}

%preun extras
%service_del_preun %{name}.service

%postun extras
%service_del_postun %{name}.service

%files
# Binaries
%{_sbindir}/coredns
# License
%license LICENSE

%files extras
%{_sbindir}/rccoredns
# Manpages
%{_mandir}/man1/coredns*
%{_mandir}/man5/corefile*
%{_mandir}/man7/coredns-*
# Configs
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/Corefile
%{_unitdir}/%{name}.service

%changelog
* Wed Mar 25 2020 Michal Jura <mjura@suse.com>
- Update to version 1.6.7:
  * Required by Kubernetes 1.18
  * make -f Makefile.doc (#3633)
  * Update date on notes (#3632)
  * Remove all shell presubmits (#3631)
  * presubmit tests (#3630)
  * presubmit: add whitespace test in go (#3629)
  * auto go mod tidy
  * build(deps): bump k8s.io/client-go from 0.17.1 to 0.17.2 (#3621)
  * auto go mod tidy
  * build(deps): bump github.com/aws/aws-sdk-go from 1.28.5 to 1.28.9 (#3625)
  * build(deps): bump github.com/prometheus/common from 0.7.0 to 0.9.1 (#3622)
* Mon Dec 16 2019 Richard Brown <rbrown@suse.com>
- Update to version 1.6.5:
  * Required by Kubernetes 1.17
  * Three new plugins: kubernetes, foreward, file
* Thu Oct 10 2019 Richard Brown <rbrown@suse.com>
- Update to version 1.6.2:
  * Required by Kubernetes 1.16
  * Three new plugins: azure, route53 and forward
* Tue Sep 10 2019 Jan Engelhardt <jengelh@inai.de>
- Fix summary of coredns-extras.
* Mon Sep  2 2019 Marco Vedovati <mvedovati@suse.com>
- Update to version 1.6.3:
  * Spelling corrections and other minor improvements and polish.
  * Two new plugins: clouddns and sign.
- Changed included from version 1.6.1:
  * Fix a panic in the hosts plugin.
  * The reload now detects changes in files imported from the main Corefile.
  * route53 increases the paging size when talking to the AWS API, this
    decreases the chances of getting throttled.
- Changed included from version 1.6.0:
  * The -cpu flag is removed from this version.
  * This release sports changes in the file plugin.
    A speed up in the log plugin and fixes in the cache and hosts plugins.
  * Upcoming deprecation: the kubernetes federation plugin will be moved to
    github.com/coredns/federation. This is likely to happen in CoreDNS 1.7.0.
- Changed included from version 1.5.2:
  * Small bugfixes and a change to Caddy’s import path
    (mholt/caddy -> caddyserver/caddy).
  * Doing a release helps plugins deal with the change better.
- Changed included from version 1.5.1:
  * Various bugfixes, better documentation and cleanups.
  * The -cpu flag is somewhat redundant (cgroups/systemd/GOMAXPROCS are better
    ways to deal with this) and we want to remove it; if you depend on it in
    some way please voice that in this PR otherwise we’ll remove it in the next
    release.
- Changed included from version 1.5.0:
  * Two new plugins in this release: grpc, and ready. And some polish and
    simplifications in the core server code.
  * The use of TIMEOUT and no_reload in file and auto have been fully deprecated.
    As is the proxy plugin.
  * And a update on two important and active bugs:
  - 2593 seems to hone in on Docker and/or the container environment being a
    contributing factor.
  - 2624 is because of TLS session negotiating in the forward plugin.
- Changed included from version 1.4.0:
  * Our first release after we became a graduated project in CNCF.
  * Deprecation notice for the next release:
  - auto will deprecate TIMEOUT and recommends the use of RELOAD (2516).
  - auto and file will deprecate NO_RELOAD and recommends the use of RELOAD
    set to 0 (2536).
  - health will revert back to report process level health without plugin status.
    A new ready plugin will make sure plugins have at least completed their
    startup sequence.
  - The proxy will be moved to an external repository and as such be
    deprecated from the default set of plugin; use the forward as a replacement.
  - The previous announced deprecations have been enacted.
  - The (unused) gRPC watch functionally was removed from the server.
* Wed Jul 24 2019 Marco Vedovati <mvedovati@suse.com>
- Add coredns-extras package to allow use of coredns in a non-containerized
  environment
* Mon Jul 22 2019 kukuk@suse.de
- Remove systemd support, not needed on openSUSE Kubic
- Build with pie (security policy)
* Tue Jul  2 2019 Daniel Orf <dorf@suse.com>
- Update to version 1.3.1:
  * log now allows multiple names to be specified
  * import was added to give it a README.md to make it’s documentation more discoverable
  * kubernetes TTL is also applied to negative responses (NXDOMAIN, etc)
- Changed included from version 1.3.0:
  * EDNS0 handling in the server and make it compliant with https://dnsflagday.net/
  * k8s_external a new plugin that allows external zones to point to Kubernetes in-cluster services.
  * rewrite fixes a bug where a rule would eat the first character of a name
  * log now supported the metadata labels. It also fixes a bug in the formatting of a plugin logging a info/failure/warning
  * forward removes the dynamic read timeout and uses a fixed value now.
  * kubernetes now checks if a zone transfer is allowed. Also allow a TTL of 0 to avoid caching in the cache plugin.
* Wed Jun  5 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  make the build dep chain cheaper by using systemd-mini.
* Tue Mar 26 2019 Daniel Orf <dorf@suse.com>
- Update spec file BuildRequires golang(API) >= 1.11
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias and rhetorics from descriptions.
- Use a single %%setup statement.
* Tue Dec 11 2018 Marco Vedovati <mvedovati@suse.com>
- Include source tarballs for each of the used golang packages created with
  _service.
  + beorn7-perks.tar.xz
  + golang-protobuf.tar.xz
  + matttproud-golang_protobuf_extensions.tar.xz
  + mholt-caddy.tar.xz
  + miekg-dns.tar.xz
  + prometheus-client_golang.tar.xz
  + prometheus-client_model.tar.xz
  + prometheus-common.tar.xz
  + prometheus-procfs.tar.xz
- Remove makearchive script, previously used to create a single source tarball.
  - makearchive.sh
* Mon Dec 10 2018 Marco Vedovati <mvedovati@suse.com>
- Initial package creation version 1.2.6
